# lhagrid

[![PyPI - Version](https://img.shields.io/pypi/v/lhagrid.svg)](https://pypi.org/project/lhagrid)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/lhagrid.svg)](https://pypi.org/project/lhagrid)

-----

Simple Read and Write interface for LHAPDFs lhagrid data files.

## Installation

```console
pip install lhagrid
```
